#
# spec file for package perl-Clone
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define cpan_name Clone
Name:           perl-Clone
Version:        0.470.0
Release:        1.3
# 0.47 -> normalize -> 0.470.0
%define cpan_version 0.47
License:        Artistic-1.0 OR GPL-1.0-or-later
Summary:        Recursively copy Perl datatypes
URL:            https://metacpan.org/release/%{cpan_name}
Source0:        https://cpan.metacpan.org/authors/id/A/AT/ATOOMIC/%{cpan_name}-%{cpan_version}.tar.gz
Source1:        cpanspec.yml
BuildRequires:  perl
BuildRequires:  perl-macros
BuildRequires:  perl(B::COW) >= 0.004
BuildRequires:  perl(Test::More) >= 0.88
Provides:       perl(Clone) = %{version}
%undefine       __perllib_provides
%{perl_requires}

%description
This module provides a 'clone()' method which makes recursive copies of
nested hash, array, scalar and reference types, including tied variables
and objects.

'clone()' takes a scalar argument and duplicates it. To duplicate lists,
arrays or hashes, pass them in by reference, e.g.

    my $copy = clone (\@array);

    # or

    my %copy = %{ clone (\%hash) };

%prep
%autosetup  -n %{cpan_name}-%{cpan_version}

find . -type f ! -path "*/t/*" ! -name "*.pl" ! -path "*/bin/*" ! -path "*/script/*" ! -path "*/scripts/*" ! -name "configure" -print0 | xargs -0 chmod 644

%build
perl Makefile.PL INSTALLDIRS=vendor OPTIMIZE="%{optflags}"
%make_build

%check
make test

%install
%perl_make_install
%perl_process_packlist
%perl_gen_filelist

%files -f %{name}.files
%doc Changes README.md

%changelog
* Sun Aug 18 2024 Tina Müller <timueller+perl@suse.de>
- updated to 0.470.0 (0.47)
  see /usr/share/doc/packages/perl-Clone/Changes
  0.47 2024-08-17 12:30:00 atoomic
  - Stop using quote as package separator
* Thu Oct 20 2022 Tina Müller <timueller+perl@suse.de>
- updated to 0.46
  see /usr/share/doc/packages/perl-Clone/Changes
  0.46 2022-10-18 20:23:00 garu
  - fix backwards compatibility with older perls (haarg)
  - bump MANIFEST to include extra tests
* Fri Apr 24 2020 <timueller+perl@suse.de>
- updated to 0.45
  see /usr/share/doc/packages/perl-Clone/Changes
  0.45 2020-04-23 14:46:00 atoomic
  - bump B::COW requirement to fix big-endian issue
* Tue Apr 21 2020 <timueller+perl@suse.de>
- updated to 0.44
  see /usr/share/doc/packages/perl-Clone/Changes
* Wed Jul 31 2019 Stephan Kulow <coolo@suse.com>
- updated to 0.43
  see /usr/share/doc/packages/perl-Clone/Changes
  0.43 2019-07-29 13:47:42  atomic
  - fix an issue when cloning a NULL mg_ptr pointer
* Fri Jul 19 2019 Stephan Kulow <coolo@suse.com>
- updated to 0.42
  see /usr/share/doc/packages/perl-Clone/Changes
  0.42 2019-07-19 23:06:04  garu
  - make handling of mg_ptr safer (ATOOMIC, Harald Jörg)
  - change license wording on some test files to
    make the entire dist released under the same
    terms as Perl itself (fixes GH#20) (GARU)
* Thu Nov  8 2018 Stephan Kulow <coolo@suse.com>
- updated to 0.41
  see /usr/share/doc/packages/perl-Clone/Changes
  0.41 2018-10-25 10:20:03  garu
  - Check the CowREFCNT of a COWed PV (ATOOMIC)
    this should fix some issues people have been
    having with 0.40 on DBD drives and DBIx::Class
  - Make buildtools files not executable (Mohammad S Anwar)
  0.40 2018-10-23 20:001:49  garu
  - reuse COWed PV when cloning (fixes RT97535) (ATOOMIC)
  - extra protection against potential infinite loop (ATOOMIC)
  - improved tests
* Sat Apr  8 2017 coolo@suse.com
- updated to 0.39
  see /usr/share/doc/packages/perl-Clone/Changes
  0.39 2017-04-07 13:06:00  garu
  - use explicit '.' in tests since it may not be in @INC
    anymore in newer perls (fixes RT120648) (PLICEASE, SIMCOP)
* Thu Apr 16 2015 coolo@suse.com
- updated to 0.38
  see /usr/share/doc/packages/perl-Clone/Changes
  0.38 2015-01-18 19:27:41  garu
  - typo fixes and improvements to the README (zmughal)
  - travis/coveralls integration (zmughal)
  0.37 2014-05-15 16:45:33  garu
  - removed Carp dependency (GARU)
  - silenced some clang warnings (JACQUESG)
  - added a README (GARU)
* Mon Dec  9 2013 coolo@suse.com
- updated to 0.36
  - fixed compilation issue on AIX and C89 (GAAS)
* Fri Oct  4 2013 coolo@suse.com
- updated to 0.35
  - SV's can be NULL (shit happens) (fixes RT86217) (Tux)
  - making tests compatible with older versions of Test::More (GARU)
* Mon Jun  3 2013 coolo@suse.com
- updated to 0.34
  - Stop skipping SvROK handling for all magical scalars. This fixes
    RT issues 67105, 79730 and 80201 (FLORA).
  - making the Changes file compliant to the CPAN::Changes spec (GARU).
  - Fixing tests when Scalar::Util::weaken is not available. As a
    result, tests should now pass even in odd OpenBSD versions (GARU).
  - removed dubious documentation on the optional parameter until
    it is 'fixed'. Right now it just increases the refcount when it's 0,
    and clones otherwise (which isn't exactly what it says). This
    fixes RT issue 57773 (GARU).
  - updated remark on Storable's dclone() to address RT issue 50174 (GARU)
  - updated Makefile.PL to include test dependencies (GARU)
* Fri Nov 18 2011 coolo@suse.com
- use original .tar.gz
* Wed Dec  1 2010 coolo@novell.com
- switch to perl_requires macro
* Fri Nov 26 2010 chris@computersalat.de
- recreated by cpanspec 1.78
- bzipped Source
* Tue Oct 19 2010 coolo@novell.com
- add perl as explicit buildrequire
* Sun Jan 10 2010 jengelh@medozas.de
- enable parallel build
* Sat Oct 17 2009 rschweikert@novell.com
- upgrade to version 0.31
  o a lot of changes, please see Changes file
* Wed Mar 26 2008 anicka@suse.cz
- package created (version 0.18)
